/*
  This file is part of the NetFax system.

  (c) Copyright 1989 by David M. Siegel. 
      All rights reserved.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation.

    This program is distributed in the hope that it will be useful, 
    but WITHOUT ANY WARRANTY; without even the implied warranty of 
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#ifndef VMS
#include <unistd.h>
#include <sys/param.h>
#endif	/* VMS */

#include <time.h>

#include "../../lib/libfax/libfax.h"

/*
 * Count the number of pages that the postscript converter generated.
 */
static int count_pages(base)
     char *base;
{
    int pages = 1;

    for (;;) {
	char filename[MAXPATHLEN];
#ifdef VMS
	sprintf(filename, "%s.g3_%d", base, pages);
#else	/* VMS */
	sprintf(filename, "%s.g3.%d", base, pages);
#endif	/* VMS */
	if (access(filename, R_OK) != 0)
	  return (pages-1);
	pages++;
    }
}


/*
 * Convert a postscript file to a set of G3 format files, using the digifax
 * driver in Ghostscript.
 */
int cvt_postscript_to_g3(in_file, out_base)
     char *in_file;
     char *out_base;
{

    char program[256];
    FILE *fp;

    /*
     * Open ghostscript converter.
     */
#ifdef VMS
    sprintf(program, "%s \"-sOUTPUTFILE=%s.g3_%%d\" %s", PS_PROG, out_base, in_file);
#else	/* VMS */
    sprintf(program, "%s -sOUTPUTFILE=%s.g3.%%d %s", PS_PROG, out_base, in_file);
#endif	/* VMS */
    if ((fp = popen(program, "w")) == NULL)
      return (-1);
    
    /*
     * We`re all done! That was simple.
     */
#ifdef VMS
    psend(fp, "quit\n", '>');
#else	/* VMS */
    fprintf(fp, "quit\n");
#endif

    /*
     * All done, wait for the conversion to complete.
     */
    pclose(fp);

    /*
     * Now count the number of pages that ghostscript wrote out.
     */
    return (count_pages(out_base));

}




int cvt_coversheet_to_g3(out_base, recipient, sender, sender_fax, pages,
SubjectA, SubjectB, SubjectC, SubjectD)
     char *out_base;
     char *recipient;
     char *sender;
     char *sender_fax;
     int pages;
     char	*SubjectA, *SubjectB, *SubjectC, *SubjectD;
{
    char PsFile[MAXPATHLEN];
    FILE *fp;
    long	clock;
    struct	tm *tm;

    sprintf(PsFile, "%s.ps", out_base);

    if ((fp = fopen(PsFile, "w")) == NULL)
      return (-1);
    
    fprintf(fp, "/recipient (%s) def\n", recipient);
    fprintf(fp, "/sender (%s) def\n", sender);
    fprintf(fp, "/returnfaxnum (%s) def\n", sender_fax);

/* The date */
    time(&clock);
    tm = localtime(&clock);
    fprintf(fp, "/date (%02d/%02d/%02d %d:%02d) def\n",
		tm->tm_mday, tm->tm_mon, tm->tm_year, tm->tm_hour, tm->tm_min);

    fprintf(fp, "/pages (%d) def\n", pages+1);

    if(SubjectA != NULL)
	fprintf(fp, "/A (%s) def\n", SubjectA);
    if(SubjectB != NULL)
	fprintf(fp, "/B (%s) def\n", SubjectB);
    if(SubjectC != NULL)
	fprintf(fp, "/C (%s) def\n", SubjectC);
    if(SubjectD != NULL)
	fprintf(fp, "/D (%s) def\n", SubjectD);

    fprintf(fp, "(%s) run\n", PS_TO_COVER_PROG);

    fclose(fp);

    if (cvt_postscript_to_g3(PsFile, out_base) < 0) {
	unlink(PsFile);
	return (-1);
    }

    unlink(PsFile);

    return (0);
}
